summaryrefslogtreecommitdiff
path: root/Userland
diff options
context:
space:
mode:
authorTimothy Flynn <trflynn89@pm.me>2023-03-23 07:39:35 -0400
committerLinus Groh <mail@linusgroh.de>2023-03-23 15:30:21 +0000
commitb74786d3c34be2c865e10988672fb5e06fb10a44 (patch)
treefc5e399fb92320a1a5bd1412339489401b64cf25 /Userland
parentf0d0459c3e90e573404fd05cf55df70a048d0be5 (diff)
downloadserenity-b74786d3c34be2c865e10988672fb5e06fb10a44.zip
LibJS: Explicitly provide all GetIterator arguments from Intl.ListFormat
This is an editorial change in the ECMA-402 spec. See: https://github.com/tc39/ecma402/commit/13895c8
Diffstat (limited to 'Userland')
-rw-r--r--Userland/Libraries/LibJS/Runtime/Intl/ListFormat.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/Userland/Libraries/LibJS/Runtime/Intl/ListFormat.cpp b/Userland/Libraries/LibJS/Runtime/Intl/ListFormat.cpp
index f44b6cb6a7..f915196b57 100644
--- a/Userland/Libraries/LibJS/Runtime/Intl/ListFormat.cpp
+++ b/Userland/Libraries/LibJS/Runtime/Intl/ListFormat.cpp
@@ -247,8 +247,8 @@ ThrowCompletionOr<Vector<String>> string_list_from_iterable(VM& vm, Value iterab
return Vector<String> {};
}
- // 2. Let iteratorRecord be ? GetIterator(iterable).
- auto iterator_record = TRY(get_iterator(vm, iterable));
+ // 2. Let iteratorRecord be ? GetIterator(iterable, sync).
+ auto iterator_record = TRY(get_iterator(vm, iterable, IteratorHint::Sync));
// 3. Let list be a new empty List.
Vector<String> list;